fixture

package
v0.17.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 24, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package fixture provides manifest fixtures for tests. It is kept free of dependencies so that unit tests can use it without pulling in the envtest setup of the test package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PodManifest

func PodManifest(images ...string) string

PodManifest renders a Pod manifest with one container per image.

Types

This section is empty.

Jump to